==> keyclic_sdk_api-1.31.2.tar.gz: lib/model/feedback_review_request_links.dart <==
part of keyclic_sdk_api.api;

class FeedbackReviewRequestLinks {
  FeedbackReviewRequestLinksSelf self = null;

  FeedbackReviewRequestLinksReviewer reviewer = null;

  FeedbackReviewRequestLinksReview review = null;

  FeedbackReviewRequestLinksItemToReview itemToReview = null;

  FeedbackReviewRequestLinks();

  @override
  String toString() {
    return 'FeedbackReviewRequestLinks[self=$self, reviewer=$reviewer, review=$review, itemToReview=$itemToReview, ]';
  }

  FeedbackReviewRequestLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    self = new FeedbackReviewRequestLinksSelf.fromJson(json['self']);
    reviewer =
        new FeedbackReviewRequestLinksReviewer.fromJson(json['reviewer']);
    review = new FeedbackReviewRequestLinksReview.fromJson(json['review']);
    itemToReview = new FeedbackReviewRequestLinksItemToReview.fromJson(
        json['itemToReview']);
  }

  Map<String, dynamic> toJson() {
    return {
      'self': self,
      'reviewer': reviewer,
      'review': review,
      'itemToReview': itemToReview
    };
  }

  static List<FeedbackReviewRequestLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<FeedbackReviewRequestLinks>()
        : json
            .map((value) => new FeedbackReviewRequestLinks.fromJson(value))
            .toList();
  }

  static Map<String, FeedbackReviewRequestLinks> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, FeedbackReviewRequestLinks>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new FeedbackReviewRequestLinks.fromJson(value));
    }
    return map;
  }
}

==> keyclic_sdk_api-1.34.5.tar.gz: lib/model/feedback_review_request_links.dart <==
part of keyclic_sdk_api.api;

class FeedbackReviewRequestLinks {
  FeedbackReviewRequestLinksSelf self = null;

  FeedbackReviewRequestLinksItemToReview itemToReview = null;

  FeedbackReviewRequestLinksOrganization organization = null;

  FeedbackReviewRequestLinksReviewer reviewer = null;

  FeedbackReviewRequestLinksReview review = null;

  FeedbackReviewRequestLinks();

  @override
  String toString() {
    return 'FeedbackReviewRequestLinks[self=$self, itemToReview=$itemToReview, organization=$organization, reviewer=$reviewer, review=$review, ]';
  }

  FeedbackReviewRequestLinks.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    self = new FeedbackReviewRequestLinksSelf.fromJson(json['self']);
    itemToReview = new FeedbackReviewRequestLinksItemToReview.fromJson(
        json['itemToReview']);
    organization = new FeedbackReviewRequestLinksOrganization.fromJson(
        json['organization']);
    reviewer =
        new FeedbackReviewRequestLinksReviewer.fromJson(json['reviewer']);
    review = new FeedbackReviewRequestLinksReview.fromJson(json['review']);
  }

  Map<String, dynamic> toJson() {
    return {
      'self': self,
      'itemToReview': itemToReview,
      'organization': organization,
      'reviewer': reviewer,
      'review': review,
    };
  }

  static List<FeedbackReviewRequestLinks> listFromJson(List<dynamic> json) {
    return json == null
        ? new List<FeedbackReviewRequestLinks>()
        : json
            .map((value) => new FeedbackReviewRequestLinks.fromJson(value))
            .toList();
  }

  static Map<String, FeedbackReviewRequestLinks> mapFromJson(
      Map<String, dynamic> json) {
    var map = new Map<String, FeedbackReviewRequestLinks>();
    if (json != null && json.length > 0) {
      json.forEach((String key, dynamic value) =>
          map[key] = new FeedbackReviewRequestLinks.fromJson(value));
    }
    return map;
  }
}
